summaryrefslogtreecommitdiff
path: root/src/main.h
diff options
context:
space:
mode:
authorDaniel Carl <danielcarl@gmx.de>2014-03-03 23:27:29 +0100
committerDaniel Carl <danielcarl@gmx.de>2014-03-03 23:27:29 +0100
commit81c0fa31cf39a74a08c74dc01611cd2c9416b211 (patch)
tree751ced26a4ae653937685af3d0071ea99ea4ad81 /src/main.h
parentc944dee2bd8d2851a070346dada1d42b467f1249 (diff)
Use 'tls-database' instead of deprecated 'ssl-ca-file'.
Diffstat (limited to 'src/main.h')
-rw-r--r--src/main.h28
1 files changed, 15 insertions, 13 deletions
diff --git a/src/main.h b/src/main.h
index f39269c..4717989 100644
--- a/src/main.h
+++ b/src/main.h
@@ -287,19 +287,21 @@ typedef struct {
} State;
typedef struct {
- time_t cookie_timeout;
- int scrollstep;
- char *home_page;
- char *download_dir;
- guint history_max;
- char *editor_command;
- guint timeoutlen; /* timeout for ambiguous mappings */
- gboolean strict_focus;
- GHashTable *headers; /* holds user defined header appended to requests */
- char *nextpattern; /* regex patter nfor prev link matching */
- char *prevpattern; /* regex patter nfor next link matching */
- char *file; /* path to the custome config file */
- char *autocmd; /* command given by --cmd option */
+ time_t cookie_timeout;
+ int scrollstep;
+ char *home_page;
+ char *download_dir;
+ guint history_max;
+ char *editor_command;
+ guint timeoutlen; /* timeout for ambiguous mappings */
+ gboolean strict_focus;
+ GHashTable *headers; /* holds user defined header appended to requests */
+ char *nextpattern; /* regex patter nfor prev link matching */
+ char *prevpattern; /* regex patter nfor next link matching */
+ char *file; /* path to the custome config file */
+ char *autocmd; /* command given by --cmd option */
+ char *cafile; /* path to the ca file */
+ GTlsDatabase *tls_db; /* tls database */
} Config;
typedef struct {